﻿--[[****************************************************************
	BankItemsFu v1.5
	5 June 2009

	Author: Xinhuan @ US Blackrock Alliance
	GuildBank-Functions added by Drudatz @ EU Kul Tiras
	****************************************************************
	Description:
		Adds BankItems to FuBar that summarises details of
		chars on the same realm.
	****************************************************************]]


-- Load only if Fubar and BankItems are loaded
if not IsAddOnLoaded("FuBar") or not IsAddOnLoaded("BankItems") then
	return
end

local L = AceLibrary("AceLocale-2.2"):new("FuBar_BankItemsFu")
local Tablet = AceLibrary("Tablet-2.0")
local Abacus = LibStub("LibAbacus-3.0")
local Dewdrop = AceLibrary("Dewdrop-2.0")

BankItemsFu = AceLibrary("AceAddon-2.0"):new("FuBarPlugin-2.0", "AceDB-2.0", "AceEvent-2.0")
local BankItemsFu = BankItemsFu
BankItemsFu.defaultPosition = 'RIGHT'
BankItemsFu.hasIcon = "Interface\\Icons\\INV_Misc_Bag_10_Blue"
BankItemsFu.canHideText = true
BankItemsFu.hasNoColor = true
BankItemsFu.defaultMinimapPosition = 345
BankItemsFu.title = "BankItemsFu"
BankItemsFu.version = "v24001"
BankItemsFu.date = "2008-05-17"

BankItemsFu:RegisterDB("BankItemsFuDB")
BankItemsFu:RegisterDefaults('profile', {
	showMoney = true,
	showBags = true,
})

L:RegisterTranslations("enUS", function() return {
	["|cffeda55fClick|r to toggle BankItems, |cffeda55fShift-Click|r to toggle BankItems Guild Bank"] = true,
	["Characters"] = true,
	["Slots"] = true,
	["Money"] = true,
	["Total"] = true,
	["Show Minimap Button"] = true,
	["Show the BankItems Minimap Button"] = true,
	["Show/Hide BankItems window"] = true,
	["Show/Hide GuildBankItems window"] = true,
	["Show Money"] = true,
	["Show Bags"] = true,
	["Purge"] = true,
	["Delete stored data of..."] = true,
	["Data of '%s of %s' deleted."] = true,
} end)

if GetLocale() == "deDE" then
	L:RegisterTranslations("deDE", function() return {
		["|cffeda55fClick|r to toggle BankItems, |cffeda55fShift-Click|r to toggle BankItems Guild Bank"] = "|cffeda55fKlicken|r um BankItems ein-/auszublenden",
		["Characters"] = "Charakter",
		["Slots"] = "Taschenplätze",
		["Money"] = "Geld",
		["Total"] = "Gesamt",
		["Show Minimap Button"] = "Minimap Button ein-/ausblenden",
		["Show the BankItems Minimap Button"] = "Minimap Button ein-/ausblenden.",
		["Show/Hide BankItems window"] = "BankItems ein-/ausblenden",
		["Show/Hide GuildBankItems window"] = "GuildBankItems ein-/ausblenden",
		["Show Money"] = "Zeige Geld",
		["Show Bags"] = "Zeige Taschenplätze",
		["Purge"] = "Löschen",
		["Delete stored data of..."] = "Lösche gespeicherte Daten von...",
		["Data of '%s of %s' deleted."] = "Daten von '%s von %s' gelöscht.",
	} end)
end

function BankItemsFu:OnInitialize()
	self.name = "BankItemsFu"
	self.hiddenframe = CreateFrame("Frame")
end

local function delay2frames(self, elapsed)
	self.delay = self.delay + 1
	if self.delay == 2 then
		BankItemsFu:UpdateText()
		BankItemsFu:UpdateTooltip()
		self:SetScript("OnUpdate", nil)
	end
end

function BankItemsFu:PrepareUpdate()
	self.hiddenframe:SetScript("OnUpdate", delay2frames)
	self.hiddenframe.delay = 0
end

function BankItemsFu:OnEnable()
	self:RegisterEvent("PLAYER_MONEY", "PrepareUpdate")
	self:RegisterEvent("BAG_UPDATE", "PrepareUpdate")
	self:RegisterEvent("BANKFRAME_OPENED", "PrepareUpdate")
	self:RegisterEvent("PLAYERBANKSLOTS_CHANGED", "PrepareUpdate")
	self:RegisterEvent("PLAYERBANKBAGSLOTS_CHANGED", "PrepareUpdate")
	self:PrepareUpdate()
end

function BankItemsFu:OnDisable()
	self:UnregisterEvent("PLAYER_MONEY")
	self:UnregisterEvent("BAG_UPDATE")
	self:UnregisterEvent("BANKFRAME_OPENED")
	self:UnregisterEvent("PLAYERBANKSLOTS_CHANGED")
	self:UnregisterEvent("PLAYERBANKBAGSLOTS_CHANGED")
end

local function toggleMinimapButton()
	BankItems_Save.ButtonShown = not BankItems_Save.ButtonShown
	BankItems_MinimapButton_Init()
end

local function toggleShowMoney()
	BankItemsFu.db.profile.showMoney = not BankItemsFu.db.profile.showMoney
	BankItemsFu:UpdateText()
end

local function toggleShowBags()
	BankItemsFu.db.profile.showBags = not BankItemsFu.db.profile.showBags
	BankItemsFu:UpdateText()
end

function BankItemsFu:OnMenuRequest(level, value)
	if level == 1 then
		Dewdrop:AddLine(
			'text', L["Show/Hide BankItems window"],
			'tooltipTitle', L["Show/Hide BankItems window"],
			'tooltipText', L["Show/Hide BankItems window"],
			'func', BankItems_SlashHandler
		)

		Dewdrop:AddLine(
			'text', L["Show/Hide GuildBankItems window"],
			'tooltipTitle', L["Show/Hide GuildBankItems window"],
			'tooltipText', L["Show/Hide GuildBankItems window"],
			'func', BankItems_DisplayGuildBank
		)

		Dewdrop:AddLine(
			'text', L["Show Minimap Button"],
			'tooltipTitle', L["Show Minimap Button"],
			'tooltipText', L["Show the BankItems Minimap Button"],
			'func', toggleMinimapButton,
			'checked', BankItems_Save.ButtonShown
		)

		Dewdrop:AddLine()
		Dewdrop:AddLine(
			'text', L["Purge"],
			'tooltipTitle', L["Purge"],
			'tooltipText', L["Delete stored data of..."],
			'hasArrow', true,
			'value', "purge"
		)
		Dewdrop:AddLine(
			'text', L["Show Money"],
			'tooltipTitle', L["Show Money"],
			'tooltipText', L["Show Money"],
			'func', toggleShowMoney,
			'checked', self.db.profile.showMoney
		)
		Dewdrop:AddLine(
			'text', L["Show Bags"],
			'tooltipTitle', L["Show Bags"],
			'tooltipText', L["Show Bags"],
			'func', toggleShowBags,
			'checked', self.db.profile.showBags
		)


	elseif level == 2 then
		if value == "purge" then
			local realm = "|"..strtrim(GetCVar("realmName"))
			local cname

			for key, value in pairs(BankItems_Save) do
				if type(value) == "table" then
					cname = string.gsub(key, realm, "")
					if string.find(key, realm) then
						if cname ~= UnitName("player") then
							Dewdrop:AddLine(
								'text', cname,
								'tooltipTitle', L["Purge"],
								'tooltipText', "... "..cname,
								'arg1', self,
								'arg2', cname,
								'func', self.DelPlayer,
								'closeWhenClicked', true
							)
						else
							Dewdrop:AddLine(
								'text', cname,
								'tooltipTitle', L["Purge"],
								'tooltipText', cname,
								'disabled', true
							)
						end
					end
				end
			end

		end
	end
end

function BankItemsFu:OnTextUpdate()
	local text = ""
	local db = self.db.profile

	if db.showMoney then
		text = text..Abacus:FormatMoneyFull(GetMoney(), true)
	end

	if db.showBags then
		local value = BankItems_Save[UnitName("player").."|"..strtrim(GetCVar("realmName"))]
		local space = 0
		local totspace = 28
		for num = 1, 28 do
			if value[num] then
				space = space + 1
			end
		end
		for bagNum = 0, 11 do
			if value["Bag"..bagNum] then
				totspace = totspace + value["Bag"..bagNum].size
				for bagItem = 1, value["Bag"..bagNum].size do
					if value["Bag"..bagNum][bagItem] then
						space = space + 1
					end
				end
			end
		end
		if not value["Bag0"] then
			totspace = totspace + GetContainerNumSlots(0)
		end

		if db.showMoney then
			text = text.." "
		end
		text = text.."|cFFFFFFFF"..space.."/"..totspace.."|r"
	end

	if not db.showMoney and not db.showBags then
		self:SetText(self.name)
	else
		self:SetText(text)
	end

end

function BankItemsFu:OnTooltipUpdate()
	local cat = Tablet:AddCategory(
		'columns', 3,
		'child_textR', 1,
		'child_textG', 1,
		'child_textB', 0,
		'child_text2R', 1,
		'child_text2G', 1,
		'child_text2B', 1,
		'text', L["Characters"],
		'text2', L["Slots"],
		'text3', L["Money"]
	)

	local total = 0
	local gspace = 0
	local gtotspace = 0
	local realm = "|"..strtrim(GetCVar("realmName"))
	local faction = UnitFactionGroup("player")

	for key, value in pairs(BankItems_Save) do
		if type(value) == "table" and strfind(key, realm, 1, true) and value.faction == faction and value.money then
				local space = 0
				local totspace = 28

				for num = 1, 28 do
					if value[num] then
						space = space + 1
					end
				end
				for bagNum = 0, 11 do
					if value["Bag"..bagNum] then
						totspace = totspace + value["Bag"..bagNum].size
						for bagItem = 1, value["Bag"..bagNum].size do
							if value["Bag"..bagNum][bagItem] then
								space = space + 1
							end
						end
					end
				end
				if not value["Bag0"] then
					totspace = totspace + GetContainerNumSlots(0)
				end

				cat:AddLine(
					'text', string.gsub(key, realm, ""),
					'text2', space.."/"..totspace,
					'text3', Abacus:FormatMoneyFull(value.money, true)
				)

				total = total + value.money
				gspace = gspace + space
				gtotspace = gtotspace + totspace
		end
	end

	cat:AddLine(
		'text', " ",
		'text2', " ",
		'text3', " "
	)
	cat:AddLine(
		'text', L["Total"],
		'text2', gspace.."/"..gtotspace,
		'text3', Abacus:FormatMoneyFull(total, true)
	)

	Tablet:SetHint(L["|cffeda55fClick|r to toggle BankItems, |cffeda55fShift-Click|r to toggle BankItems Guild Bank"])
end

function BankItemsFu:OnClick(a, b)
	if IsShiftKeyDown() then
		BankItems_DisplayGuildBank()
	else
		BankItems_SlashHandler()
	end
end

function BankItemsFu:DelPlayer(name)
	BankItems_DelPlayer(name.."|"..strtrim(GetCVar("realmName")))
	BankItems_Chat(format(L["Data of '%s of %s' deleted."],name,strtrim(GetCVar("realmName"))))
end
